/// <reference types="node" />

import { defineConfig, devices } from "@playwright/test"

const isCI = !!process.env.CI

const dappUrl = isCI ? "http://localhost:4173" : "http://localhost:5173"

/**
* See https://playwright.dev/docs/test-configuration.
*/
export default defineConfig({
    testDir: "./tests",
    /* Run tests in files in parallel */
    fullyParallel: true,
    /* Fail the build on CI if you accidentally left test.only in the source code. */
    forbidOnly: isCI,
    /* Retry on CI only */
    retries: process.env.CI ? 2 : 0,
    /* Opt out of parallel tests on CI. */
    workers: process.env.CI ? 1 : undefined,
    /* Reporter to use. See https://playwright.dev/docs/test-reporters */
    reporter: "html",
    /* Shared settings for all the projects below. See https://playwright.dev/docs/api/class-testoptions. */
    use: {
        /* Base URL to use in actions like `await page.goto('/')`. */
        baseURL: dappUrl,
        permissions: ["clipboard-read"],
        /* Collect trace when retrying the failed test. See https://playwright.dev/docs/trace-viewer */
        trace: "on-first-retry",
    },

    /* Configure projects for major browsers */
    projects: [
        {
            name: "chromium",
            use: { ...devices["Desktop Chrome"] },
        },
        {
            name: "chrome",
            use: { ...devices["Desktop Chrome"], channel: "chrome" },
        },
    ],

    /* Run your local dev server before starting the tests */
    webServer: {
        command: isCI ? "pnpm preview --strictPort" : "pnpm dev --strictPort",
        cwd: "../demo",
        url: dappUrl,
        timeout: 120 * 1000,
        reuseExistingServer: !isCI,
    },
})
